<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fn="http://www.w3.org/2005/xpath-functions" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" >
	<xsl:output version="1.0" method="xml" indent="yes" encoding="UTF-8"/>

	<xsl:variable name="VOUCHER_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="VOUCHER_DATE">
		<xsl:value-of select="concat(substring($VOUCHER_DATE_ORIG,1,4),substring($VOUCHER_DATE_ORIG,6,2),substring($VOUCHER_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="DELIVERY_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='DELIVERY_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="DELIVERY_DATE">
		<xsl:value-of select="concat(substring($DELIVERY_DATE_ORIG,1,4),substring($DELIVERY_DATE_ORIG,6,2),substring($DELIVERY_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="PAYMENT_TERMS_DUE_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='PAYMENT']/*[@itemId='PAYMENT_TERMS_DUE_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="PAYMENT_TERMS_DUE_DATE">
		<xsl:value-of select="concat(substring($PAYMENT_TERMS_DUE_DATE_ORIG,1,4),substring($PAYMENT_TERMS_DUE_DATE_ORIG,6,2),substring($PAYMENT_TERMS_DUE_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="INVOICE_START_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='INVOICING_PERIOD_START_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="INVOICE_START_DATE">
		<xsl:value-of select="concat(substring($INVOICE_START_DATE_ORIG,1,4),substring($INVOICE_START_DATE_ORIG,6,2),substring($INVOICE_START_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="INVOICE_END_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='INVOICING_PERIOD_END_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="INVOICE_END_DATE">
		<xsl:value-of select="concat(substring($INVOICE_END_DATE_ORIG,1,4),substring($INVOICE_END_DATE_ORIG,6,2),substring($INVOICE_END_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="PRECEDING_INVOICE_REFERENCE_DATE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='PRECEDING_INVOICE_REFERENCE_DATE']/@value"/>
	</xsl:variable>
	<xsl:variable name="PRECEDING_INVOICE_REFERENCE_DATE">
		<xsl:value-of select="concat(substring($PRECEDING_INVOICE_REFERENCE_DATE_ORIG,1,4),substring($PRECEDING_INVOICE_REFERENCE_DATE_ORIG,6,2),substring($PRECEDING_INVOICE_REFERENCE_DATE_ORIG,9,2))"></xsl:value-of>
	</xsl:variable>

	<xsl:variable name="SHIPPING_ADDRESS_LINE_ORIG">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE']/@value"/>
	</xsl:variable>

	<xsl:variable name="CURRENCY">
		<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/*[@itemId='CURRENCY']/@value"/>
	</xsl:variable>

	<xsl:template match="/DataDefinition">
		<rsm:CrossIndustryInvoice
		  xmlns:rsm="urn:un:unece:uncefact:data:standard:CrossIndustryInvoice:100"
		  xmlns:ram="urn:un:unece:uncefact:data:standard:ReusableAggregateBusinessInformationEntity:100"
		  xmlns:udt="urn:un:unece:uncefact:data:standard:UnqualifiedDataType:100"
		  xmlns:qdt="urn:un:unece:uncefact:data:standard:QualifiedDataType:100"
    >
			<rsm:ExchangedDocumentContext>
				<ram:GuidelineSpecifiedDocumentContextParameter>
					<ram:ID>urn:cen.eu:en16931:2017</ram:ID>
				</ram:GuidelineSpecifiedDocumentContextParameter>
			</rsm:ExchangedDocumentContext>

			<rsm:ExchangedDocument>
				<xsl:if test="DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_ID']/@value != ''">
					<ram:ID>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/*[@itemId='VOUCHER_ID']/@value"/>
					</ram:ID>
				</xsl:if>
				<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemChoice[@itemId='DOCUMENT_TYPE']/@value != ''">
					<ram:TypeCode>
						<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemChoice[@itemId='DOCUMENT_TYPE']/@value"/>
					</ram:TypeCode>
				</xsl:if>
				<ram:IssueDateTime>
					<udt:DateTimeString format="102">
						<xsl:value-of select="$VOUCHER_DATE"/>
					</udt:DateTimeString>
				</ram:IssueDateTime>

				<xsl:if test="DataItemGroup[@itemId='HEADER']/*[@itemId='INVOICE_NOTE']/@value != ''">
					<ram:IncludedNote>
						<ram:Content>
							<xsl:value-of select="DataItemGroup[@itemId='HEADER']/*[@itemId='INVOICE_NOTE']/@value"/>
						</ram:Content>
					</ram:IncludedNote>
				</xsl:if>
			</rsm:ExchangedDocument>

			<rsm:SupplyChainTradeTransaction>

				<!--Items -->

				<xsl:for-each select="DataItemCollection[@itemId='ITEM_DETAILS']/DataItem">
					<ram:IncludedSupplyChainTradeLineItem>
						<ram:AssociatedDocumentLineDocument>
							<xsl:if test="DataItemString[@itemId='ITEM_LINE_ID']/@value != ''">
								<ram:LineID>
									<xsl:value-of select="DataItemString[@itemId='ITEM_LINE_ID']/@value"/>
								</ram:LineID>
							</xsl:if>
							<xsl:if test="DataItemString[@itemId='ITEM_NOTE']/@value != ''">
								<ram:IncludedNote>
									<ram:Content>
										<xsl:value-of select="DataItemString[@itemId='ITEM_NOTE']/@value"/>
									</ram:Content>
								</ram:IncludedNote>
							</xsl:if>
						</ram:AssociatedDocumentLineDocument>

						<ram:SpecifiedTradeProduct>
							<!--ram:GlobalID schemeID="0160">...</ram:GlobalID-->

							<xsl:if test="DataItemString[@itemId='ITEM_SELLER_ID']/@value != ''">
								<ram:SellerAssignedID>
									<xsl:value-of select="DataItemString[@itemId='ITEM_SELLER_ID']/@value"/>
								</ram:SellerAssignedID>
							</xsl:if>

							<xsl:if test="DataItemString[@itemId='ITEM_BUYER_ID']/@value != ''">
								<ram:BuyerAssignedID>
									<xsl:value-of select="DataItemString[@itemId='ITEM_BUYER_ID']/@value"/>
								</ram:BuyerAssignedID>
							</xsl:if>

							<xsl:if test="DataItemString[@itemId='ITEM_NAME']/@value != ''">
								<ram:Name>
									<xsl:value-of select="DataItemString[@itemId='ITEM_NAME']/@value"/>
								</ram:Name>
							</xsl:if>
							<!--ram:Description/>...</ram:Description-->
						</ram:SpecifiedTradeProduct>

						<ram:SpecifiedLineTradeAgreement>
							<xsl:if test="DataItemString[@itemId='REFERENCED_PURCHASE_ORDER_LINE_ID']/@value != ''">
								<ram:BuyerOrderReferencedDocument>
									<ram:LineID>
										<xsl:value-of select="DataItemString[@itemId='REFERENCED_PURCHASE_ORDER_LINE_ID']/@value"/>
									</ram:LineID>
								</ram:BuyerOrderReferencedDocument>
							</xsl:if>
							<ram:GrossPriceProductTradePrice>
								<ram:ChargeAmount>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_GROSS_PRICE']/@value, '0.0000')"/>
								</ram:ChargeAmount>
								<xsl:if test="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000') != 'NaN'">
									<ram:BasisQuantity>
										<xsl:attribute name="unitCode">
											<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
										</xsl:attribute>
										<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000')"/>
									</ram:BasisQuantity>
								</xsl:if>
								<xsl:if test="DataItemNumeric[@itemId='ITEM_PRICE_DISCOUNT']/@value != ''">
									<ram:AppliedTradeAllowanceCharge>
										<ram:ChargeIndicator>
											<udt:Indicator>false</udt:Indicator>
										</ram:ChargeIndicator>
										<ram:ActualAmount>
											<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_PRICE_DISCOUNT']/@value, '0.0000')"/>
										</ram:ActualAmount>
									</ram:AppliedTradeAllowanceCharge>
								</xsl:if>
							</ram:GrossPriceProductTradePrice>
							<ram:NetPriceProductTradePrice>
								<ram:ChargeAmount>
									<xsl:choose>
										<xsl:when test="DataItemNumeric[@itemId='ITEM_NET_PRICE']/@value != ''">
											<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_NET_PRICE']/@value, '0.0000')"/>
										</xsl:when>
										<xsl:otherwise>
											<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_GROSS_PRICE']/@value, '0.0000')"/>
										</xsl:otherwise>
									</xsl:choose>
								</ram:ChargeAmount>
								<xsl:if test="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000') != 'NaN'">
									<ram:BasisQuantity>
										<xsl:attribute name="unitCode">
											<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
										</xsl:attribute>
										<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_PRICE_BASE_QUANTITY']/@value, '0.0000')"/>
									</ram:BasisQuantity>
								</xsl:if>
							</ram:NetPriceProductTradePrice>
						</ram:SpecifiedLineTradeAgreement>

						<ram:SpecifiedLineTradeDelivery>
							<ram:BilledQuantity>
								<xsl:attribute name="unitCode">
									<xsl:value-of select="DataItemChoice[@itemId='ITEM_UNIT']/@value"/>
								</xsl:attribute>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_QUANTITY']/@value, '0.0000')"/>
							</ram:BilledQuantity>
						</ram:SpecifiedLineTradeDelivery>

						<ram:SpecifiedLineTradeSettlement>
							<ram:ApplicableTradeTax>
								<ram:TypeCode>VAT</ram:TypeCode>
								<xsl:if test="DataItemChoice[@itemId='ITEM_VAT_CATEGORY']/@value != ''">
									<ram:CategoryCode>
										<xsl:value-of select="DataItemChoice[@itemId='ITEM_VAT_CATEGORY']/@value"/>
									</ram:CategoryCode>
								</xsl:if>
								<ram:RateApplicablePercent>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_VAT_PERCENT']/@value, '0.00')"/>
								</ram:RateApplicablePercent>
							</ram:ApplicableTradeTax>
							<xsl:variable name="INVOICE_LINE_START_DATE_ORIG">
								<xsl:value-of select="DataItemDate[@itemId='ITEM_PERIOD_START_DATE']/@value"/>
							</xsl:variable>
							<xsl:variable name="INVOICE_LINE_START_DATE">
								<xsl:value-of select="concat(substring($INVOICE_LINE_START_DATE_ORIG,1,4),substring($INVOICE_LINE_START_DATE_ORIG,6,2),substring($INVOICE_LINE_START_DATE_ORIG,9,2))"></xsl:value-of>
							</xsl:variable>

							<xsl:variable name="INVOICE_LINE_END_DATE_ORIG">
								<xsl:value-of select="DataItemDate[@itemId='ITEM_PERIOD_END_DATE']/@value"/>
							</xsl:variable>
							<xsl:variable name="INVOICE_LINE_END_DATE">
								<xsl:value-of select="concat(substring($INVOICE_LINE_END_DATE_ORIG,1,4),substring($INVOICE_LINE_END_DATE_ORIG,6,2),substring($INVOICE_LINE_END_DATE_ORIG,9,2))"></xsl:value-of>
							</xsl:variable>

							<xsl:if test="$INVOICE_LINE_END_DATE_ORIG != ''">
								<ram:BillingSpecifiedPeriod>
									<ram:StartDateTime>
										<udt:DateTimeString format="102">
											<xsl:value-of select="$INVOICE_LINE_START_DATE"/>
										</udt:DateTimeString>
									</ram:StartDateTime>
									<ram:EndDateTime>
										<udt:DateTimeString format="102">
											<xsl:value-of select="$INVOICE_LINE_END_DATE"/>
										</udt:DateTimeString>
									</ram:EndDateTime>
								</ram:BillingSpecifiedPeriod>
							</xsl:if>
							<ram:SpecifiedTradeSettlementLineMonetarySummation>
								<ram:LineTotalAmount>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ITEM_TOTAL_AMOUNT']/@value, '0.00')"/>
								</ram:LineTotalAmount>
							</ram:SpecifiedTradeSettlementLineMonetarySummation>

							<xsl:if test="DataItemString[@itemId='ITEM_OBJECT_IDENTIFIER']/@value != ''">
								<ram:AdditionalReferencedDocument>
									<ram:IssuerAssignedID>
										<xsl:value-of select="DataItemString[@itemId='ITEM_OBJECT_IDENTIFIER']/@value"/>
									</ram:IssuerAssignedID>
									<ram:TypeCode>130</ram:TypeCode>
								</ram:AdditionalReferencedDocument>
							</xsl:if>

						</ram:SpecifiedLineTradeSettlement>
					</ram:IncludedSupplyChainTradeLineItem>
				</xsl:for-each>

				<ram:ApplicableHeaderTradeAgreement>
					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='ROUTING_ID']/@value != ''">
						<ram:BuyerReference>
							<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='ROUTING_ID']/@value"/>
						</ram:BuyerReference>
					</xsl:if>
					<ram:SellerTradeParty>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ID']/@value != ''">
							<ram:ID>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ID']/@value"/>
							</ram:ID>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_GLN']/@value != ''">
							<ram:GlobalID schemeID="0088">
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_GLN']/@value"/>
							</ram:GlobalID>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value != ''">
							<ram:Name>
								<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
							</ram:Name>
						</xsl:if>
						<ram:SpecifiedLegalOrganization>
							<ram:TradingBusinessName>
								<xsl:choose>
									<xsl:when test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TRADING_NAME']/@value != ''">
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TRADING_NAME']/@value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
									</xsl:otherwise>
								</xsl:choose>
							</ram:TradingBusinessName>
						</ram:SpecifiedLegalOrganization>

						<ram:DefinedTradeContact>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_NAME']/@value != ''">
								<ram:PersonName>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_NAME']/@value"/>
								</ram:PersonName>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_PHONE']/@value != ''">
								<ram:TelephoneUniversalCommunication>
									<ram:CompleteNumber>
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_PHONE']/@value"/>
									</ram:CompleteNumber>
								</ram:TelephoneUniversalCommunication>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_EMAIL']/@value != ''">
								<ram:EmailURIUniversalCommunication>
									<ram:URIID>
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_CONTACT_EMAIL']/@value"/>
									</ram:URIID>
								</ram:EmailURIUniversalCommunication>
							</xsl:if>
						</ram:DefinedTradeContact>

						<!--ram:GlobalID schemeID="0088">...</ram:GlobalID-->
						<ram:PostalTradeAddress>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_ZIP']/@value != ''">
								<ram:PostcodeCode>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_ZIP']/@value"/>
								</ram:PostcodeCode>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE']/@value != ''">
								<ram:LineOne>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE']/@value"/>
								</ram:LineOne>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE2']/@value != ''">
								<ram:LineTwo>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE2']/@value"/>
								</ram:LineTwo>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE3']/@value != ''">
								<ram:LineThree>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_LINE3']/@value"/>
								</ram:LineThree>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_CITY']/@value != ''">
								<ram:CityName>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_ADDRESS_CITY']/@value"/>
								</ram:CityName>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemChoice[@itemId='SELLER_ADDRESS_COUNTRY']/@value != ''">
								<ram:CountryID>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemChoice[@itemId='SELLER_ADDRESS_COUNTRY']/@value"/>
								</ram:CountryID>
							</xsl:if>
						</ram:PostalTradeAddress>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_ID']/@value != ''">
							<ram:SpecifiedTaxRegistration>
								<ram:ID schemeID="VA">
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_ID']/@value"/>
								</ram:ID>
							</ram:SpecifiedTaxRegistration>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_REG_ID']/@value != ''">
							<ram:SpecifiedTaxRegistration>
								<ram:ID schemeID="FC">
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_TAX_REG_ID']/@value"/>
								</ram:ID>
							</ram:SpecifiedTaxRegistration>
						</xsl:if>
					</ram:SellerTradeParty>
					<ram:BuyerTradeParty>
						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_ID']/@value != ''">
							<ram:ID>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_ID']/@value"/>
							</ram:ID>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_GLN']/@value != ''">
							<ram:GlobalID schemeID="0088">
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_GLN']/@value"/>
							</ram:GlobalID>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_NAME']/@value != ''">
							<ram:Name>
								<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_NAME']/@value"/>
							</ram:Name>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_TRADING_NAME']/@value != ''">
							<ram:SpecifiedLegalOrganization>
								<ram:TradingBusinessName>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_TRADING_NAME']/@value"/>
								</ram:TradingBusinessName>
							</ram:SpecifiedLegalOrganization>
						</xsl:if>
						<ram:DefinedTradeContact>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_NAME']/@value != ''">
								<ram:PersonName>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_NAME']/@value"/>
								</ram:PersonName>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_PHONE']/@value != ''">
								<ram:TelephoneUniversalCommunication>
									<ram:CompleteNumber>
										<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_PHONE']/@value"/>
									</ram:CompleteNumber>
								</ram:TelephoneUniversalCommunication>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_EMAIL']/@value != ''">
								<ram:EmailURIUniversalCommunication>
									<ram:URIID>
										<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_CONTACT_EMAIL']/@value"/>
									</ram:URIID>
								</ram:EmailURIUniversalCommunication>
							</xsl:if>
						</ram:DefinedTradeContact>
						<ram:PostalTradeAddress>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_ZIP']/@value != ''">
								<ram:PostcodeCode>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_ZIP']/@value"/>
								</ram:PostcodeCode>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE']/@value != ''">
								<ram:LineOne>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE']/@value"/>
								</ram:LineOne>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE2']/@value != ''">
								<ram:LineTwo>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE2']/@value"/>
								</ram:LineTwo>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE3']/@value != ''">
								<ram:LineThree>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_LINE3']/@value"/>
								</ram:LineThree>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_CITY']/@value != ''">
								<ram:CityName>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemString[@itemId='BUYER_ADDRESS_CITY']/@value"/>
								</ram:CityName>
							</xsl:if>
							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemChoice[@itemId='BUYER_ADDRESS_COUNTRY']/@value != ''">
								<ram:CountryID>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='BUYER_ADDRESS']/DataItemChoice[@itemId='BUYER_ADDRESS_COUNTRY']/@value"/>
								</ram:CountryID>
							</xsl:if>
						</ram:PostalTradeAddress>

						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_ENDPOINT_ID']/@value != ''">
							<ram:URIUniversalCommunication>
								<ram:URIID schemeID="EM">
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_ENDPOINT_ID']/@value"/>
								</ram:URIID>
							</ram:URIUniversalCommunication>
						</xsl:if>

						<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_TAX_ID']/@value != ''">
							<ram:SpecifiedTaxRegistration>
								<ram:ID schemeID="VA">
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemString[@itemId='BUYER_TAX_ID']/@value"/>
								</ram:ID>
							</ram:SpecifiedTaxRegistration>
						</xsl:if>

					</ram:BuyerTradeParty>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='SALES_ORDER_REFERENCE_ID']/@value != ''">
						<ram:SellerOrderReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='SALES_ORDER_REFERENCE_ID']/@value"/>
							</ram:IssuerAssignedID>
						</ram:SellerOrderReferencedDocument>
					</xsl:if>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='BUYER_ORDER_ID']/@value != ''">
						<ram:BuyerOrderReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='BUYER_ORDER_ID']/@value"/>
							</ram:IssuerAssignedID>
						</ram:BuyerOrderReferencedDocument>
					</xsl:if>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='CONTRACT_REFERENCE_ID']/@value != ''">
						<ram:ContractReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='CONTRACT_REFERENCE_ID']/@value"/>
							</ram:IssuerAssignedID>
						</ram:ContractReferencedDocument>
					</xsl:if>

					<xsl:for-each select="DataItemCollection[@itemId='ATTACH']/DataItem">
						<ram:AdditionalReferencedDocument>
							<xsl:if test="DataItemString[@itemId='ATTACH_ID']/@value != ''">
								<ram:IssuerAssignedID>
									<xsl:value-of select="DataItemString[@itemId='ATTACH_ID']/@value"/>
								</ram:IssuerAssignedID>
							</xsl:if>
							<xsl:if test="DataItemChoice[@itemId='ATTACH_TYPE']/@value != ''">
								<ram:TypeCode>
									<xsl:value-of select="DataItemChoice[@itemId='ATTACH_TYPE']/@value"/>
								</ram:TypeCode>
							</xsl:if>
							<xsl:if test="DataItemString[@itemId='ATTACH_NAME']/@value != ''">
								<xsl:if test="DataItemString[@itemId='ATTACH_NAME']/@value != ''">
									<ram:Name>
										<xsl:value-of select="DataItemString[@itemId='ATTACH_NAME']/@value"/>
									</ram:Name>
								</xsl:if>
							</xsl:if>
							<xsl:if test="DataItemFile[@itemId='ATTACH_FILE'] != ''">
								<ram:AttachmentBinaryObject>
									<xsl:attribute name="mimeCode">
										<xsl:value-of select="DataItemFile[@itemId='ATTACH_FILE']/@mimeCode"/>
									</xsl:attribute>
									<xsl:attribute name="filename">
										<xsl:value-of select="DataItemFile[@itemId='ATTACH_FILE']/@filename"/>
									</xsl:attribute>

									<xsl:value-of select="DataItemFile[@itemId='ATTACH_FILE']"/>
								</ram:AttachmentBinaryObject>
							</xsl:if>
						</ram:AdditionalReferencedDocument>
					</xsl:for-each>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='TENDER_LOT_ID']/@value != ''">
						<ram:AdditionalReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='TENDER_LOT_ID']/@value"/>
							</ram:IssuerAssignedID>
							<ram:TypeCode>50</ram:TypeCode>
						</ram:AdditionalReferencedDocument>
					</xsl:if>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='INVOICED_OBJECT_ID']/@value != ''">
						<ram:AdditionalReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='INVOICED_OBJECT_ID']/@value"/>
							</ram:IssuerAssignedID>
							<ram:TypeCode>130</ram:TypeCode>
						</ram:AdditionalReferencedDocument>
					</xsl:if>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PROJECT_REFERENCE_ID']/@value != ''">
						<ram:SpecifiedProcuringProject>
							<ram:ID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PROJECT_REFERENCE_ID']/@value"/>
							</ram:ID>
							<ram:Name></ram:Name>
						</ram:SpecifiedProcuringProject>
					</xsl:if>

				</ram:ApplicableHeaderTradeAgreement>

				<ram:ApplicableHeaderTradeDelivery>

					
						<ram:ShipToTradeParty>

							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_ID']/@value != ''">
								<ram:ID>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_ID']/@value"/>
								</ram:ID>
							</xsl:if>

							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_GLN']/@value != ''">
								<ram:GlobalID schemeID="0088">
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_GLN']/@value"/>
								</ram:GlobalID>
							</xsl:if>

							<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_NAME']/@value != ''">
								<ram:Name>
									<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_NAME']/@value"/>
								</ram:Name>
							</xsl:if>
							
							<xsl:if test="$SHIPPING_ADDRESS_LINE_ORIG != ''">

								<ram:PostalTradeAddress>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_ZIP']/@value != ''">
										<ram:PostcodeCode>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_ZIP']/@value"/>
										</ram:PostcodeCode>
									</xsl:if>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE']/@value != ''">
										<ram:LineOne>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE']/@value"/>
										</ram:LineOne>
									</xsl:if>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE2']/@value != ''">
										<ram:LineTwo>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE2']/@value"/>
										</ram:LineTwo>
									</xsl:if>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE3']/@value != ''">
										<ram:LineThree>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_LINE3']/@value"/>
										</ram:LineThree>
									</xsl:if>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_CITY']/@value != ''">
										<ram:CityName>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemString[@itemId='SHIPPING_ADDRESS_CITY']/@value"/>
										</ram:CityName>
									</xsl:if>
									<xsl:if test="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemChoice[@itemId='SHIPPING_ADDRESS_COUNTRY']/@value != ''">
										<ram:CountryID>
											<xsl:value-of select="DataItemGroup[@itemId='BUYER']/DataItemGroup[@itemId='SHIPPING_ADDRESS']/DataItemChoice[@itemId='SHIPPING_ADDRESS_COUNTRY']/@value"/>
										</ram:CountryID>
									</xsl:if>
								</ram:PostalTradeAddress>
							</xsl:if>

						</ram:ShipToTradeParty>
					

					<ram:ActualDeliverySupplyChainEvent>
						<ram:OccurrenceDateTime>
							<udt:DateTimeString format="102">
								<xsl:value-of select="$DELIVERY_DATE"/>
							</udt:DateTimeString>
						</ram:OccurrenceDateTime>
					</ram:ActualDeliverySupplyChainEvent>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='DESPATCH_ADVICE_REFERENCE_ID']/@value != ''">
						<ram:DespatchAdviceReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='DESPATCH_ADVICE_REFERENCE_ID']/@value"/>
							</ram:IssuerAssignedID>
						</ram:DespatchAdviceReferencedDocument>
					</xsl:if>

				</ram:ApplicableHeaderTradeDelivery>

				<ram:ApplicableHeaderTradeSettlement>
					<xsl:if test="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_REFERENCE']/@value != ''">
						<ram:PaymentReference>
							<xsl:value-of select="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_REFERENCE']/@value"/>
						</ram:PaymentReference>
					</xsl:if>
					<ram:InvoiceCurrencyCode>
						<xsl:value-of select="$CURRENCY"/>
					</ram:InvoiceCurrencyCode>
					<ram:SpecifiedTradeSettlementPaymentMeans>
						<xsl:if test="DataItemGroup[@itemId='PAYMENT']/DataItemChoice[@itemId='PAYMENT_MEANS_TYPE_CODE']/@value != ''">
							<ram:TypeCode>
								<xsl:value-of select="DataItemGroup[@itemId='PAYMENT']/DataItemChoice[@itemId='PAYMENT_MEANS_TYPE_CODE']/@value"/>
							</ram:TypeCode>
						</xsl:if>
						<xsl:if test="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_MEANS_TYPE_TEXT']/@value != ''">
							<ram:Information>
								<xsl:value-of select="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_MEANS_TYPE_TEXT']/@value"/>
							</ram:Information>
						</xsl:if>
						<!--Note: The entries from the UNTDID 4461 code list shall be used. Distinction should be made between SEPA- and non- SEPA payments and between credit payments, direct debits, card payments and other instruments.-->
						<ram:PayeePartyCreditorFinancialAccount>
							<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_IBAN']/@value != ''">
								<ram:IBANID>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_IBAN']/@value"/>
								</ram:IBANID>
							</xsl:if>
							<ram:AccountName>
								<xsl:choose>
									<xsl:when test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_PAYMENT_ACCOUNT_NAME']/@value != ''">
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_PAYMENT_ACCOUNT_NAME']/@value"/>
									</xsl:when>
									<xsl:otherwise>
										<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_NAME']/@value"/>
									</xsl:otherwise>
								</xsl:choose>
							</ram:AccountName>
						</ram:PayeePartyCreditorFinancialAccount>
						<xsl:if test="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_BIC']/@value != ''">
							<ram:PayeeSpecifiedCreditorFinancialInstitution>
								<ram:BICID>
									<xsl:value-of select="DataItemGroup[@itemId='SELLER']/DataItemString[@itemId='SELLER_BIC']/@value"/>
								</ram:BICID>
							</ram:PayeeSpecifiedCreditorFinancialInstitution>
						</xsl:if>
					</ram:SpecifiedTradeSettlementPaymentMeans>

					<!-- VAT / TAX -->

					<xsl:for-each select="DataItemCollection[@itemId='VAT']/DataItem">
						<ram:ApplicableTradeTax>
							<ram:CalculatedAmount>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='VAT_AMOUNT']/@value, '0.00')"/>
							</ram:CalculatedAmount>
							<ram:TypeCode>VAT</ram:TypeCode>

							<xsl:if test="format-number(DataItemNumeric[@itemId='VAT_PERCENT']/@value, '0.00') = '0.00' and DataItemChoice[@itemId='VAT_CATEGORY']/@value != 'Z' and /DataDefinition/DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='VAT_EXEPT_REASON_TEXT']/@value != ''">
								<ram:ExemptionReason>
									<xsl:value-of select="/DataDefinition/DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='VAT_EXEPT_REASON_TEXT']/@value"/>
								</ram:ExemptionReason>
							</xsl:if>

							<ram:BasisAmount>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='BASIS_AMOUNT']/@value, '0.00')"/>
							</ram:BasisAmount>
							<xsl:if test="DataItemChoice[@itemId='VAT_CATEGORY']/@value != ''">
								<ram:CategoryCode>
									<xsl:value-of select="DataItemChoice[@itemId='VAT_CATEGORY']/@value"/>
								</ram:CategoryCode>
							</xsl:if>
							<ram:RateApplicablePercent>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='VAT_PERCENT']/@value, '0.00')"/>
							</ram:RateApplicablePercent>

						</ram:ApplicableTradeTax>
					</xsl:for-each>

					<xsl:if test="$INVOICE_START_DATE_ORIG != ''">
						<ram:BillingSpecifiedPeriod>
							<ram:StartDateTime>
								<udt:DateTimeString format="102">
									<xsl:value-of select="$INVOICE_START_DATE"/>
								</udt:DateTimeString>
							</ram:StartDateTime>
							<ram:EndDateTime>
								<udt:DateTimeString format="102">
									<xsl:value-of select="$INVOICE_END_DATE"/>
								</udt:DateTimeString>
							</ram:EndDateTime>
						</ram:BillingSpecifiedPeriod>
					</xsl:if>

					<xsl:for-each select="DataItemCollection[@itemId='ALLOWANCE_CHARGE']/DataItem">

						<ram:SpecifiedTradeAllowanceCharge>
							<ram:ChargeIndicator>
								<udt:Indicator>
									<xsl:if test="DataItemChoice[@itemId='ALLOWANCE_CHARGE_TYPE']/@value = 'ALLOWANCE'">false</xsl:if>
									<xsl:if test="DataItemChoice[@itemId='ALLOWANCE_CHARGE_TYPE']/@value = 'CHARGE'">true</xsl:if>
								</udt:Indicator>
							</ram:ChargeIndicator>

							<ram:ActualAmount>
								<xsl:value-of select="format-number(DataItemNumeric[@itemId='ALLOWANCE_CHARGE_AMOUNT']/@value, '0.00')"/>
							</ram:ActualAmount>
							<xsl:if test="DataItemString[@itemId='ALLOWANCE_CHARGE_REASON']/@value != ''">
								<ram:Reason>
									<xsl:value-of select="DataItemString[@itemId='ALLOWANCE_CHARGE_REASON']/@value"/>
								</ram:Reason>
							</xsl:if>

							<ram:CategoryTradeTax>
								<ram:TypeCode>VAT</ram:TypeCode>
								<xsl:if test="DataItemChoice[@itemId='ALLOWANCE_CHARGE_VAT_CATEGORY']/@value != ''">
									<ram:CategoryCode>
										<xsl:value-of select="DataItemChoice[@itemId='ALLOWANCE_CHARGE_VAT_CATEGORY']/@value"/>
									</ram:CategoryCode>
								</xsl:if>
								<ram:RateApplicablePercent>
									<xsl:value-of select="format-number(DataItemNumeric[@itemId='ALLOWANCE_CHARGE_VAT_PERCENT']/@value, '0.00')"/>
								</ram:RateApplicablePercent>
							</ram:CategoryTradeTax>

						</ram:SpecifiedTradeAllowanceCharge>

					</xsl:for-each>

					<ram:SpecifiedTradePaymentTerms>
						<xsl:if test="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_TERMS_DESCRIPTION']/@value != ''">
							<ram:Description>
								<xsl:value-of select="DataItemGroup[@itemId='PAYMENT']/DataItemString[@itemId='PAYMENT_TERMS_DESCRIPTION']/@value"/>
							</ram:Description>
						</xsl:if>
						<xsl:if test="$PAYMENT_TERMS_DUE_DATE_ORIG != ''">
							<ram:DueDateDateTime>
								<udt:DateTimeString format="102">
									<xsl:value-of select="$PAYMENT_TERMS_DUE_DATE"/>
								</udt:DateTimeString>
							</ram:DueDateDateTime>
						</xsl:if>
					</ram:SpecifiedTradePaymentTerms>

					<ram:SpecifiedTradeSettlementHeaderMonetarySummation>
						<ram:LineTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='LINE_TOTAL_AMOUNT']/@value, '0.00')"/>
						</ram:LineTotalAmount>
						<ram:ChargeTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='CHARGE_AMOUNT']/@value, '0.00')"/>
						</ram:ChargeTotalAmount>
						<ram:AllowanceTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='ALLOWANCE_AMOUNT']/@value, '0.00')"/>
						</ram:AllowanceTotalAmount>
						<ram:TaxBasisTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='NET_AMOUNT']/@value, '0.00')"/>
						</ram:TaxBasisTotalAmount>
						<ram:TaxTotalAmount>
							<xsl:attribute name="currencyID">
								<xsl:value-of select="$CURRENCY"/>
							</xsl:attribute>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='TAX_AMOUNT']/@value, '0.00')"/>
						</ram:TaxTotalAmount>
						<ram:GrandTotalAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='GROSS_AMOUNT']/@value, '0.00')"/>
						</ram:GrandTotalAmount>
						<xsl:if test="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='ROUNDING_AMOUNT']/@value, '0.00') != 'NaN' and format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='ROUNDING_AMOUNT']/@value, '0.00') != '0.00'">
							<ram:RoundingAmount>
								<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='ROUNDING_AMOUNT']/@value, '0.00')"/>
							</ram:RoundingAmount>
						</xsl:if>
						<ram:TotalPrepaidAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='PREPAID_AMOUNT']/@value, '0.00')"/>
						</ram:TotalPrepaidAmount>
						<ram:DuePayableAmount>
							<xsl:value-of select="format-number(DataItemGroup[@itemId='SUM']/DataItemNumeric[@itemId='DUE_PAYABLE_AMOUNT']/@value, '0.00')"/>
						</ram:DuePayableAmount>
					</ram:SpecifiedTradeSettlementHeaderMonetarySummation>

					<xsl:if test="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PRECEDING_INVOICE_REFERENCE_ID']/@value != ''">
						<ram:InvoiceReferencedDocument>
							<ram:IssuerAssignedID>
								<xsl:value-of select="DataItemGroup[@itemId='HEADER']/DataItemString[@itemId='PRECEDING_INVOICE_REFERENCE_ID']/@value"/>
							</ram:IssuerAssignedID>
							<xsl:if test="$PRECEDING_INVOICE_REFERENCE_DATE_ORIG != ''">
								<ram:FormattedIssueDateTime>
									<qdt:DateTimeString format="102">
										<xsl:value-of select="$PRECEDING_INVOICE_REFERENCE_DATE"/>
									</qdt:DateTimeString>
								</ram:FormattedIssueDateTime>
							</xsl:if>
						</ram:InvoiceReferencedDocument>
					</xsl:if>

				</ram:ApplicableHeaderTradeSettlement>

			</rsm:SupplyChainTradeTransaction>
		</rsm:CrossIndustryInvoice>
	</xsl:template>
</xsl:stylesheet>